==> mysql-workbench_5.2.38+dfsg.orig.tar.xz: mysql-workbench-5.2.38/library/forms/mforms/sectionbox.h <==
/* 
 * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#ifndef _MFORMS_SECTIONBOX_H_
#define _MFORMS_SECTIONBOX_H_

#include "mforms/box.h"
#include "mforms/drawbox.h"
#include "cairo/cairo.h"

/**
 * The section box is a container with a hidable area (collapse/expand). It provides a header with action buttons
 * and can use tabs for switchable content.
 */
namespace mforms {

  class HeaderBox;
    
  class MFORMS_EXPORT SectionBox : public Box
  {
    friend class HeaderBox;

  private:
    HeaderBox* _header;
    View* _content;
    std::string _title;
    bool _expandable;
    bool _expanded;
    cairo_surface_t* _unexpandable_icon;
    cairo_surface_t* _unexpanded_icon;
    cairo_surface_t* _expanded_icon;

  public:
    SectionBox(bool expandable, const std::string& title, bool header_mode= false);
    ~SectionBox();

    void set_content(View* page);
    void toggle();
    void set_expanded(bool expanded);
    bool get_expanded() { return _expanded; }
  };

#ifndef DOXYGEN_SHOULD_SKIP_THIS
#ifndef SWIG
  // Private class, so don't expose it to Python.
  class HeaderBox : public DrawBox
  {
  private:
    SectionBox* _owner;
    double _caption_offset;
    double _icon_left;
    double _icon_right;
    double _icon_top;
    double _icon_bottom;
    bool _header_mode; // Draw in special style (rounded corners and gradient).

    void draw_background(cairo_t* cr, int width, int height);
  public:
    HeaderBox(SectionBox* owner, bool header_mode);

    void repaint(cairo_t* cr, int x, int y, int w, int h);
    void mouse_down(int button, int x, int y);
  };
#endif
#endif

}

#endif // _MFORMS_SECTIONBOX_H_

==> mysql-workbench_6.3.8+dfsg.orig.tar.xz: mysql-workbench-6.3.8/library/forms/mforms/sectionbox.h <==
/* 
 * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */

#pragma once

#include "mforms/box.h"
#include "mforms/drawbox.h"
#include "cairo/cairo.h"

/**
 * The section box is a container with a hidable area (collapse/expand). It provides a header with action buttons
 * and can use tabs for switchable content.
 */
namespace mforms {

  class HeaderBox;
    
  class MFORMS_EXPORT SectionBox : public Box
  {
    friend class HeaderBox;

  private:
    HeaderBox* _header;
    View* _content;
    std::string _title;
    bool _expandable;
    bool _expanded;
    cairo_surface_t* _unexpandable_icon;
    cairo_surface_t* _unexpanded_icon;
    cairo_surface_t* _expanded_icon;

  public:
    SectionBox(bool expandable, const std::string& title, bool header_mode= false);
    ~SectionBox();

    void set_content(View* page);
    void toggle();
    void set_expanded(bool expanded);
    bool get_expanded() { return _expanded; }
  };

#ifndef DOXYGEN_SHOULD_SKIP_THIS
#ifndef SWIG
  // Private class, so don't expose it to Python.
  class HeaderBox : public DrawBox
  {
  private:
    SectionBox* _owner;
    double _caption_offset;
    double _icon_left;
    double _icon_right;
    double _icon_top;
    double _icon_bottom;
    bool _header_mode; // Draw in special style (rounded corners and gradient).

    void draw_background(cairo_t* cr, int width, int height);
  public:
    HeaderBox(SectionBox* owner, bool header_mode);

    void repaint(cairo_t* cr, int x, int y, int w, int h);
    bool mouse_down(mforms::MouseButton button, int x, int y);
  };
#endif
#endif

}
